@@ -15,9 +15,10 @@ AWSCLI
 ----
 A Universal Command Line Environment for Amazon Web Services.
 """
+
 import os
 
-__version__ = '1.32.69'
+__version__ = '1.36.22'
 
 #
 # Get our data path to be added to botocore's search path
@@ -40,8 +41,16 @@ EnvironmentVariables = {
 }
 
 
-SCALAR_TYPES = set([
-    'string', 'float', 'integer', 'long', 'boolean', 'double',
-    'blob', 'timestamp'
-])
+SCALAR_TYPES = set(
+    [
+        'string',
+        'float',
+        'integer',
+        'long',
+        'boolean',
+        'double',
+        'blob',
+        'timestamp',
+    ]
+)
 COMPLEX_TYPES = set(['structure', 'map', 'list'])
